<?php

declare(strict_types=1);

namespace mirzaev\site\account\models;

// Project files
use mirzaev\site\account\models\account,
  mirzaev\site\account\models\traits\instance;

// Фреймворк ArangoDB
use mirzaev\arangodb\collection;

// Библиотека для ArangoDB
use ArangoDBClient\Document as _document;

// Встроенные библиотеки
use exception;

/**
 * Модель приглашения
 *
 * @package mirzaev\site\account\models
 * @author Arsen Mirzaev Tatyano-Muradovich <arsen@mirzaev.sexy>
 */
final class invite extends core
{
  use instance;

  /**
   * Коллекция
   */
  final public const COLLECTION = 'invite';

  /**
   * Инстанция документа приглашения в базе данных
   */
  protected readonly _document $document;

  /**
   * Прочитать
   *
   * @param string $key Ключ приглашения
   * @param array &$errors Реестр ошибок
   *
   * @return ?self Инстанция приглашения, если оно найдено
   */
  public static function read(string $key, array &$errors = []): ?self
  {
    try {
      if (collection::init(static::$arangodb->session, self::COLLECTION)) {
        // Инициализирована коллекция

        // Инициализация инстанции приглашения
        $invite = new self;

        // Поиск приглашения
        $instance = $invite->instance(collection::search(
          static::$arangodb->session,
          sprintf(
            <<<AQL
              FOR d IN %s
                FILTER d.key == '%s' && d.active == true
                RETURN d
            AQL,
            self::COLLECTION,
            $key
          )
        ));

        // Exit (success)
        return $instance instanceof _document ? $invite : throw new exception('Не удалось найти инстанцию приглашения в базе данных');
      } else throw new exception('Не удалось инициализировать коллекцию');
    } catch (exception $e) {
      // Запись в реестр ошибок
      $errors[] = [
        'text' => $e->getMessage(),
        'file' => $e->getFile(),
        'line' => $e->getLine(),
        'stack' => $e->getTrace()
      ];
    }

    return null;
  }

  public function from(): ?account
  {
    return null;
  }
}
