<?php

declare(strict_types=1);

namespace svoboda\accounts;

// Framework for PHP
use mirzaev\minimal\core,
	mirzaev\minimal\route;

// Debug
ini_set('error_reporting', E_ALL);
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);

// Initializing path to the public directory 
define('INDEX', __DIR__);

// Initializing path to the project root directory
define('ROOT', INDEX . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR);

// Initializing path to the directory of views 
define('VIEWS', realpath('..' . DIRECTORY_SEPARATOR . 'views'));

// Initializing path to the directory of settings 
define('SETTINGS', realpath('..' . DIRECTORY_SEPARATOR . 'settings'));

// Initializing path to the directory of the storage 
define('STORAGE', realpath('..' . DIRECTORY_SEPARATOR . 'storage'));

// Initializing default theme for the views templater
define('THEME', 'default');

// Initializing dependencies
require ROOT . 'vendor' . DIRECTORY_SEPARATOR . 'autoload.php';

// Initializing core
$core = new core(namespace: __NAMESPACE__);

// Initializing routes
$core->router
	->write('/', new route('index', 'index'), 'GET')
	->write('/initialization', new route('account', 'initialization'), 'POST')
	->write('/connect/vk', new route('account', 'connect'), 'GET')
	->write('/settings', new route('account', 'settings'), 'GET')
	->write('/api/password/generate', new route('api', 'password'), 'POST')
	->write('/session/authentication', new route('session', 'authentication'), 'POST')
	->write('/session/password', new route('session', 'password'), 'POST')
	->write('/session/invite', new route('session', 'invite'), 'POST')
	->write('/system/hotline', new route('hotline', 'index'), 'GET')
	->write('/system/graph', new route('graph', 'index'), 'GET')
;

// Handling request
$core->start();
